#############################################################################
##
#W cctree.gi                Package Coclass                      Bettina Eick
##
## check the automorphism group conjecture in the graph G(p,c)
##

CoclassHeaderByLimit := function( p, d, c, limit )
    local grps, i, des, j, s, t, n, r;

    # check
    if d > c+1 then return; fi;

    # start with elementary abelian group p^d
    grps := [ElementaryAbelianGroup(p^d)];
    i := 1;
    n := List([1..c], x -> 0);

    # compute iterated descendants
    while i <= Length(grps) do
        Print("starting group ",i," of ",Length(grps),"\n");

        # get desired descendants
        des := PqDescendants( grps[i] : OrderBound := limit );
        des := Filtered(des, x -> CoclassPGroup(x)<=c);
        Print("  got ",Length(des), " Descendants to check \n");

        # check
        for j in [1..Length(des)] do
            if not IsAbelian(des[j]) then

                # print
                Print("  checking ",j);
                Print(" -- order ",Length(Factors(Size(des[j]))));
                Print(" -- coclass ",CoclassPGroup(des[j]),"\n");

                # check
                s := AutomorphismGroupPGroup(des[j]).size;
                t := Size(des[j]);
                if not IsInt(s/t) then Error("counterexample"); fi;

                # remember
                r := CoclassPGroup(des[j]);
                n[r] := n[r]+1;
            fi;
        od;
           
        # add for next round
        des := Filtered(des, IsCapable);
        des := Filtered(des, x -> Length(Factors(Size(x))) < limit );
        Append( grps, des );

        # save some space and go on
        grps[i] := false;
        i := i+1;
    od;

    return n;
end;

IsRoot := function(roots, G)
    local F, L;
    F := PqStandardPresentation(G);
    L := ListPresentation(F);
    return L in roots;
end;

AutFacSize := function(G)
    return AutomorphismGroupPGroup(G).size/Size(G);
end;

CoclassHeaderByRoots := function( p, d, c, roots )
    local grps, i, des, j, n, r, limit;

    # check
    if d > c+1 then return; fi;

    # start with elementary abelian group p^d
    grps := [ElementaryAbelianGroup(p^d)];
    i := 1;
    n := List([1..c], x -> 0);

    # compute iterated descendants
    while i <= Length(grps) do
        Print("  starting group ",i," of ",Length(grps),"\n");

        # get order bound
        limit := c + 1 + ClassPGroup(grps[i]);

        # get desired descendants
        des := PqDescendants( grps[i] : OrderBound := limit );
        des := Filtered(des, x -> CoclassPGroup(x)<=c);
        des := Filtered(des, x -> not IsRoot(roots, x));
        Print("    got ",Length(des), " Descendants to check \n");

        # check
        for j in [1..Length(des)] do
            if not IsAbelian(des[j]) then

                # print
                Print("    checking ",j);
                Print(" -- order ",Length(Factors(Size(des[j]))));
                Print(" -- coclass ",CoclassPGroup(des[j]),"\n");

                # check
                if not IsInt(AutFacSize(des[j])) then 
                    Error("counterexample");
                fi;

                # remember
                r := CoclassPGroup(des[j]);
                n[r] := n[r]+1;
            fi;
        od;
           
        # add for next round
        Append( grps, Filtered(des, IsCapable) );

        # save some space and go on
        grps[i] := false;
        i := i+1;
    od;

    return n;
end;

GetRoots := function( grps, class )
    local p, roots, G, K, H;
    p := grps[1]!.prime;
    roots := [];
    for G in grps do
        K := PcpGroupToFpGroup(G);
        H := PqStandardPresentation( K : Prime := p, ClassBound := class );
        Add( roots, ListPresentation(H) );
    od;
    return roots;
end;

CheckCoclassTwig := function( H, K )
    local grps, twig, i, j, next, d, des, cap, aut;

    grps := [H];
    twig := [[AutomorphismGroupPGroup(H).size]];
    i := 1;

    # check
    if not IsInt(twig[1][1]/Size(H)) then Error("counterexample"); fi;

    while Length(grps) > 0 do
        Print("      next level with ",Length(grps)," groups \n");
        i := i + 1;
        next := [];
        twig[i] := [];
        for d in grps do
            des := PqDescendants( d : StepSize := 1 );
            cap := Filtered( des, IsCapable );

            # cut off the main line in the first step
            if i = 2 then 
                aut := List( cap, x -> false );
                cap := EliminateMainLine( K, cap, aut ); 
                des := Concatenation(cap, Filtered(des, IsTerminal));
            fi;

            # check
            aut := List(des, x -> AutomorphismGroupPGroup(x).size);
            for j in [1..Length(des)] do
                if not IsInt(aut[j]/Size(des[j])) then 
                    Error("counterexample");
                fi;
            od;

            Append(twig[i], aut);
            Append(next, cap);

        od;
        Sort(twig[i]);

        # reset for next level
        grps := next;
    od;

    return twig;
end;

CheckCoclassBranchByProPGroup := function( G )
    local T, class, d, m, M, U, C, l, p, F, twig, H, K, i, root;

    # get translations
    T := G;
    class := 1;
    while not IsFreeAbelian(T) do
        T := CommutatorSubgroup(T, G); Cgs(T);
        class := class+1;
    od;

    # get d and class
    d := Length(Cgs(T));
    class := class+d+1;
    Print("  period ",d,"\n");

    # get action and l
    m := LinearActionOnPcp( Pcp(G, T), Pcp(T) );
    M := MatrixAlgebra(Rationals, d );
    U := Subalgebra(M, m);
    C := Centralizer(M,U);
    l := Length(Basis(C));
    Print("  factor ",l,"\n");

    # set up 
    p := G!.prime;
    F := PcpGroupToFpGroup( G );

    # set up for iteration
    twig := [];

    # do the initial 2*d twigs
    for i in [1..2*d] do
        Print("    compute twig ",class+i-1,"\n");
        H := Pq( F : Prime := p, ClassBound := class+i-1 );
        K := Pq( F : Prime := p, ClassBound := class+i );
        twig[i] := CheckCoclassTwig( H, K );
    od;

    # add twigs until periodicity sets in
    class := class+i-1;
    while not twig{[1..d]}*p^(d+l) = twig{[d+1..2*d]} do

        # eliminate 1st twig and reset class
        twig := twig{[2..2*d]};
        class := class+1;

        # construct new twig
        Print("    compute twig ",class,"\n");
        H := Pq( F : Prime := p, ClassBound := class );
        K := Pq( F : Prime := p, ClassBound := class+1 );
        twig[2*d] := CheckCoclassTwig( H, K );
    od;

    # get root
    class := class-2*d+1;
    H := PqStandardPresentation( F : Prime := p, ClassBound := class );
    root := ListPresentation(H);

    return rec( d := d, l := l, twigs := twig{[1..d]}, root := root );
end;

RootOfBranch := function( G )
    local T, class, d, m, M, U, C, l, p, H, K, root;

    # get translations
    T := G;
    class := 1;
    while not IsFreeAbelian(T) do
        T := CommutatorSubgroup(T, G); Cgs(T);
        class := class+1;
    od;

    # get d and class
    d := Length(Cgs(T));
    class := class+d+1;
    Print("  period ",d,"\n");

    # get action and l
    m := LinearActionOnPcp( Pcp(G, T), Pcp(T) );
    M := MatrixAlgebra(Rationals, d );
    U := Subalgebra(M, m);
    C := Centralizer(M,U);
    l := Length(Basis(C));
    Print("  factor ",l,"\n");

    # get root
    p := G!.prime;
    K := PcpGroupToFpGroup(G);
    H := PqStandardPresentation( K : Prime := p, ClassBound := class );
    root := ListPresentation(H);

    return rec( d := d, l := l, root := root );
end;

MainLineQ16Coclass3 := function(n)
    local F, f, a, b, t, r, G, g, H, K, R;   

    F := FreeGroup(3);
    f := GeneratorsOfGroup(F);
    a := f[1]; b := f[2]; t := f[3];
    r := [ Comm(t,t^a), Comm(t,(t^a)^2), a^b*a, b^-2*a^4, t^(a^4)*t,
    t^b * t^(365*5-3*512) * ((t^(-3*365+2*512))^a) * (t^(-1*365+512))^(a^2)
        * (t^(-2*365+512))^(a^3) ];

    G := F/r; g := GeneratorsOfGroup(G);
    H := Subgroup( G, [g[1], g[2]*g[3]]);
    K := FpGroupPresentation(PresentationSubgroup(G,H));
    R := Image(EpimorphismQuotientSystem(PQuotient (K, 2, n)));
    return R;
end;

CheckCoclassBranchQ16Coclass3 := function( class )
    local twig, i, H, K, root;

    # set up for iteration
    twig := [];

    # do the initial 2*d twigs
    for i in [1..2*4] do
        Print("    compute twig ",class+i-1,"\n");
        H := MainLineQ16Coclass3(class+i-1);
        K := MainLineQ16Coclass3(class+i);
        twig[i] := CheckCoclassTwig( H, K );
    od;

    # add twigs until periodicity sets in
    class := class+i-1;
    while not twig{[1..4]}*2^(4+2) = twig{[4+1..2*4]} do

        # eliminate 1st twig and reset class
        twig := twig{[2..2*4]};
        class := class+1;

        # construct new twig
        Print("    compute twig ",class,"\n");
        H := MainLineQ16Coclass3(class+i-1);
        K := MainLineQ16Coclass3(class+i);
        twig[2*4] := CheckCoclassTwig( H, K );
    od;

    # get root
    class := class-2*4+1;
    K := MainLineQ16Coclass3(class);
    H := PqStandardPresentation( K : Prime := 2, ClassBound := class );
    root := ListPresentation(H);

    return rec( d := 4, l := 2, twigs := twig{[1..4]}, root := root );
end;

InfoProPGroup := function( G )
    local r, a, b;
    r := List(Igs(G), x -> RelativeOrderPcp(x));
    a := First([1..Length(r)], x -> r[x]=0) - 1;
    b := a+PositionNonZero(r{[a+1..Length(r)]});
    return [a, Length(r)-b+1];
end;

CheckCoclassGraph := function( p, s )
    local grps, roots, branches, header, i, r;

    # get pro-p-groups
    TRANSLATE := true;
    grps := ClassifyProPGroupsByCoclass(p, s);
    grps := Flat(grps);

    # set up
    roots := [];
    header := [];
    branches := List( grps, x -> InfoProPGroup(x));

    # check branches
    for i in [1..Length(grps)] do
        Print("\n\n");
        Print("checking branch ",i," of ",Length(grps),"\n");
        r := CheckCoclassBranchByProPGroup( grps[i] );
        #r := RootOfBranch( grps[i] );
        Add( branches[i], r.d );
        Add( branches[i], r.l );
        Add( branches[i], r.root[1] );
        Add( roots, r.root );
    od;

    # add p-adic branches for p = 2
    if p = 2 and s = 3 then
        #r := CheckCoclassBranchQ16Coclass3(7);
        Add( branches, [4,0,4,2,10]);
        Add( roots,  [ 10, 
                     [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], 
                       [ 3, 2, 9, -1, 7, -1, 6, -1 ], [ 4, 2 ], 
                       [ 5, 2 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2 ], [ 9, 2 ],
                       [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ],
                       [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ],
                       [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ],
                       [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 7, -1, 6, -1, 5, -1 ],
                       [ 4, -1, 3, -1, 4, 1, 3, 1, 7, -1 ],
                       [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ],
                       [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ],
                       [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1 ],
                       [ 6, -1, 1, -1, 6, 1, 1, 1, 8, -1 ],
                       [ 6, -1, 2, -1, 6, 1, 2, 1, 10, -1, 9, -1, 8, -1 ],
                       [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1 ],
                       [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1 ],
                       [ 6, -1, 5, -1, 6, 1, 5, 1, 10, -1 ],
                       [ 7, -1, 1, -1, 7, 1, 1, 1, 10, -1, 9, -1 ],
                       [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ],
                       [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ],
                       [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ],
                       [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ],
                       [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ] );
 
    elif p = 2 and s > 3 then
        Error("not yet implemented");
    fi;

    # check header
    for i in [1..s+1] do
        Print("\n\n");
        Print("checking header with ",i," generators \n");
        r := CoclassHeaderByRoots( p, i, s, roots );
        Add( header, r );
    od;

    return rec( branches := branches, 
                header := header );
end;

rootsG23 := 
[ [ 5, 
      [ [ 1, 2 ], [ 2, 2 ], [ 3, 2, 5, -1, 4, -1 ], [ 4, 2, 5, -1 ], [ 5, 2 ],
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 5, -1 ] ] ], 
  [ 6, [ [ 1, 2 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 6, -1, 5, -1 ], 
          [ 5, 2, 6, -1 ], [ 6, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 6, -1 ] ] ], 
  [ 6, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1, 5, -1 ], [ 4, 2 ], 
          [ 5, 2, 6, -1 ], [ 6, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 6, -1 ] ] ], 
  [ 6, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1, 3, -1 ], [ 3, 2, 6, -1, 5, -1 ], 
          [ 4, 2 ], [ 5, 2, 6, -1 ], [ 6, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ] ] ], 
  [ 7, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 7, -1, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 7, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 7, -1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 7, -1, 6, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2 ], 
          [ 5, 2, 8, -1, 7, -1 ], [ 6, 2, 8, -1 ], [ 7, 2 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 8, -1, 7, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 7, -1, 6, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 7, [ [ 1, 2 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2 ], [ 5, 2, 7, -1, 6, -1 ], 
          [ 6, 2, 7, -1 ], [ 7, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 7, -1, 6, -1 ], [ 5, 2 ], 
          [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2, 6, -1, 4, -1 ], [ 3, 2 ], [ 4, 2, 7, -1, 6, -1 ], 
          [ 5, 2 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 7, [ [ 1, 2, 5, -1 ], [ 2, 2 ], [ 3, 2, 5, -1 ], [ 4, 2, 7, -1, 6, -1 ], 
          [ 5, 2 ], [ 6, 2, 7, -1 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2, 4, -1 ], [ 3, 2 ], [ 4, 2 ], 
          [ 5, 2, 7, -1, 6, -1 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], 
          [ 8, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 8, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2, 6, -1, 4, -1 ], [ 3, 2, 5, -1 ], 
          [ 4, 2, 7, -1, 6, -1 ], [ 5, 2 ], [ 6, 2, 8, -1, 7, -1 ], 
          [ 7, 2, 8, -1 ], [ 8, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 7, [ [ 1, 2, 5, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 7, -1, 6, -1 ], 
          [ 5, 2 ], [ 6, 2, 7, -1 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2 ], [ 3, 2, 4, -1 ], [ 4, 2 ], 
          [ 5, 2, 7, -1, 6, -1 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], 
          [ 8, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 8, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2, 4, -1 ], [ 3, 2 ], [ 4, 2 ], 
          [ 5, 2, 7, -1, 6, -1 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], 
          [ 8, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 8, -1 ] ] ], 
  [ 8, [ [ 1, 2 ], [ 2, 2, 5, -1 ], [ 3, 2, 4, -1 ], [ 4, 2, 7, -1, 6, -1 ], 
          [ 5, 2, 6, -1 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 7, [ [ 1, 2, 5, -1 ], [ 2, 2, 6, -1, 4, -1 ], [ 3, 2 ], 
          [ 4, 2, 7, -1, 6, -1 ], [ 5, 2 ], [ 6, 2, 7, -1 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2, 4, -1 ], [ 3, 2, 6, -1, 5, -1 ], [ 4, 2 ], 
          [ 5, 2, 7, -1, 6, -1 ], [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 8, -1 ], 
          [ 8, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 7, -1, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 8, -1, 7, -1 ], [ 6, 2, 8, -1, 7, -1 ], 
          [ 7, 2, 9, -1, 8, -1 ], [ 8, 2, 9, -1 ], [ 9, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 6, -1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 9, -1 ] ] ], 
  [ 7, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 7, -1, 5, -1 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 7, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 7, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 7, -1, 6, -1 ], 
          [ 4, 2, 7, -1, 6, -1, 5, -1 ], [ 5, 2, 8, -1, 7, -1 ], 
          [ 6, 2, 8, -1, 7, -1 ], [ 7, 2, 9, -1, 8, -1 ], [ 8, 2, 9, -1 ], 
          [ 9, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 6, -1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 9, -1 ] ] ], 
  [ 7, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], [ 3, 2, 7, -1, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 6, -1 ], [ 6, 2, 7, -1 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1, 6, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], [ 3, 2, 7, -1, 6, -1 ], 
          [ 4, 2, 7, -1, 6, -1, 5, -1 ], [ 5, 2 ], [ 6, 2, 8, -1, 7, -1 ], 
          [ 7, 2, 9, -1, 8, -1 ], [ 8, 2, 9, -1 ], [ 9, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1, 5, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 7, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 9, -1 ] ] ], 
  [ 7, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1, 3, -1 ], [ 3, 2, 7, -1, 5, -1 ], 
          [ 4, 2, 6, -1 ], [ 5, 2, 7, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ] ] ], 
  [ 8, [ [ 1, 2, 5, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 8, -1, 7, -1 ], 
          [ 5, 2 ], [ 6, 2, 8, -1 ], [ 7, 2 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 7, -1, 6, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 8, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 9, -1, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 9, -1, 8, -1 ], [ 6, 2, 9, -1 ], [ 7, 2, 10, -1, 9, -1 ], 
          [ 8, 2, 10, -1 ], [ 9, 2 ], [ 10, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 9, -1, 8, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], [ 3, 2, 8, -1, 7, -1 ], [ 4, 2 ], 
          [ 5, 2, 8, -1 ], [ 6, 2, 8, -1 ], [ 7, 2 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 6, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2, 7, -1, 5, -1 ], 
          [ 3, 2, 8, -1, 7, -1, 6, -1 ], [ 4, 2 ], [ 5, 2, 9, -1, 8, -1 ], 
          [ 6, 2 ], [ 7, 2, 10, -1, 9, -1 ], [ 8, 2, 10, -1 ], [ 9, 2 ], 
          [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2, 7, -1, 5, -1 ], [ 3, 2, 8, -1, 7, -1 ], 
          [ 4, 2, 6, -1 ], [ 5, 2, 8, -1 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 8, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 8, -1, 7, -1 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 8, -1 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 8, -1, 7, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 7, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ] ] ], 
  [ 9, [ [ 1, 2, 5, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2 ], [ 5, 2 ], 
          [ 6, 2, 9, -1, 8, -1 ], [ 7, 2, 9, -1 ], [ 8, 2 ], [ 9, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 4, -1, 1, -1, 4, 1, 1, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 9, -1, 8, -1, 6, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 9, -1, 8, -1 ], [ 6, 2 ], [ 7, 2, 9, -1 ], [ 8, 2 ], 
          [ 9, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 8, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 9, -1, 8, -1 ], [ 6, 2 ], [ 7, 2, 10, -1, 9, -1 ], 
          [ 8, 2, 10, -1 ], [ 9, 2 ], [ 10, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 9, -1, 8, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2, 8, -1, 7, -1 ], 
          [ 5, 2, 8, -1 ], [ 6, 2 ], [ 7, 2, 9, -1 ], [ 8, 2, 10, -1 ], 
          [ 9, 2 ], [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 8, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 10, -1, 9, -1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1, 8, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 10, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], [ 3, 2 ], [ 4, 2 ], [ 5, 2 ], 
          [ 6, 2, 9, -1, 8, -1 ], [ 7, 2, 9, -1 ], [ 8, 2 ], [ 9, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 8, -1, 6, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ] ] ], 
  [ 9, [ [ 1, 2, 4, -1 ], [ 2, 2, 9, -1, 5, -1 ], [ 3, 2 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 9, -1, 8, -1 ], [ 6, 2 ], [ 7, 2, 9, -1 ], [ 8, 2 ], 
          [ 9, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 9, -1, 7, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 8, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2, 9, -1, 5, -1 ], 
          [ 3, 2, 10, -1, 7, -1, 6, -1 ], [ 4, 2 ], [ 5, 2, 9, -1, 8, -1 ], 
          [ 6, 2, 10, -1, 9, -1 ], [ 7, 2, 10, -1, 9, -1 ], [ 8, 2, 10, -1 ], 
          [ 9, 2 ], [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 8, -1, 7, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 8, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 10, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 10, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 10, -1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 10, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2, 7, -1, 5, -1 ], 
          [ 3, 2, 9, -1, 7, -1, 6, -1 ], [ 4, 2, 8, -1, 7, -1 ], 
          [ 5, 2, 8, -1 ], [ 6, 2, 9, -1 ], [ 7, 2, 9, -1 ], [ 8, 2, 10, -1 ],
          [ 9, 2 ], [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 9, -1, 8, -1, 7, -1, 6, -1, 5, 
              -1 ], [ 4, -1, 3, -1, 4, 1, 3, 1, 10, -1, 9, -1, 8, -1, 7, -1 ],
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1, 8, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 9, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 10, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ], 
  [ 9, [ [ 1, 2 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2 ], [ 5, 2 ], 
          [ 6, 2, 9, -1, 8, -1 ], [ 7, 2, 9, -1 ], [ 8, 2 ], [ 9, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 4, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 6, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 8, -1, 7, -1, 6, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1, 7, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 7, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 9, -1 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 10, -1 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2 ], [ 9, 2 ], 
          [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 9, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 9, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 10, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ] ] ], 
  [ 11, [ [ 1, 2, 4, -1 ], [ 2, 2, 9, -1, 7, -1 ], [ 3, 2 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 10, -1 ], [ 6, 2 ], [ 7, 2, 11, -1 ], [ 8, 2 ], [ 9, 2 ], 
          [ 10, 2 ], [ 11, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 10, -1, 8, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 11, -1, 10, -1, 9, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 11, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 11, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 11, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 11, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ] ] ], 
  [ 11, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 6, -1 ], 
          [ 5, 2, 10, -1 ], [ 6, 2 ], [ 7, 2, 11, -1 ], [ 8, 2 ], [ 9, 2 ], 
          [ 10, 2 ], [ 11, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 10, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 11, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 11, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 10, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 11, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 12, -1, 10, -1 ], [ 6, 2 ], [ 7, 2, 11, -1 ], 
          [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 10, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 11, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 12, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 11, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 11, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2, 11, -1, 5, -1 ], 
          [ 3, 2, 9, -1, 7, -1, 6, -1 ], [ 4, 2 ], [ 5, 2, 12, -1, 10, -1 ], 
          [ 6, 2 ], [ 7, 2, 11, -1 ], [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], 
          [ 11, 2 ], [ 12, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 10, -1, 9, -1, 7, -1, 6, -1, 5, 
              -1 ], [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 10, -1, 7, -1 
             ], [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 11, -1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 12, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 11, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 11, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], 
          [ 4, 2, 12, -1, 11, -1, 9, -1 ], [ 5, 2 ], [ 6, 2 ], 
          [ 7, 2, 12, -1, 11, -1 ], [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], 
          [ 11, 2 ], [ 12, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 11, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2, 11, -1, 9, -1, 5, -1 ], 
          [ 3, 2, 9, -1, 7, -1, 6, -1 ], [ 4, 2, 12, -1, 11, -1, 9, -1 ], 
          [ 5, 2 ], [ 6, 2 ], [ 7, 2, 12, -1, 11, -1 ], [ 8, 2, 12, -1 ], 
          [ 9, 2 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 7, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 11, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 11, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 11, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2 ], [ 5, 2 ], 
          [ 6, 2 ], [ 7, 2, 12, -1, 11, -1 ], [ 8, 2, 12, -1 ], [ 9, 2 ], 
          [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ]
            , [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 12, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 12, -1, 11, -1, 10, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 12, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 12, -1, 11, -1, 10, -1, 8, -1 ], 
          [ 4, 2, 6, -1 ], [ 5, 2 ], [ 6, 2 ], [ 7, 2, 11, -1 ], 
          [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 11, -1, 10, -1, 8, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 11, -1, 10, -1, 8, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 11, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 11, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 12, -1, 10, -1, 9, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 12, -1, 11, -1, 10, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 12, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2, 7, -1 ], [ 3, 2, 12, -1, 11, -1, 9, -1 ], 
          [ 4, 2, 6, -1 ], [ 5, 2 ], [ 6, 2 ], [ 7, 2, 11, -1 ], 
          [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 9, -1, 8, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 11, -1, 9, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 12, -1, 10, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 11, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ] ] ], 
  [ 12, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 6, -1 ], [ 5, 2 ], 
          [ 6, 2 ], [ 7, 2, 11, -1 ], [ 8, 2, 12, -1 ], [ 9, 2 ], [ 10, 2 ], 
          [ 11, 2 ], [ 12, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 11, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 11, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 11, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 11, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 11, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], 
          [ 3, 2, 11, -1, 9, -1, 7, -1, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 13, -1, 11, -1, 9, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 8, 2, 13, -1, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], 
          [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 11, -1, 7, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 11, -1, 9, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 9, -1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 13, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 12, -1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 11, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 11, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 11, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 13, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 13, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 13, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 5, -1, 10, 1, 5, 1, 13, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 13, -1, 12, -1, 11, -1, 6, -1 ], 
          [ 4, 2 ], [ 5, 2, 13, -1, 12, -1, 11, -1, 9, -1 ], 
          [ 6, 2, 13, -1, 12, -1, 11, -1 ], [ 7, 2 ], 
          [ 8, 2, 13, -1, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], 
          [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 11, -1, 9, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 11, -1, 9, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 13, -1, 11, -1, 10, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 13, -1, 12, -1, 11, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 12, -1, 11, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 13, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 13, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 5, -1, 10, 1, 5, 1, 13, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 13, -1, 11, -1, 6, -1 ], 
          [ 4, 2 ], [ 5, 2, 13, -1, 11, -1, 10, -1 ], 
          [ 6, 2, 13, -1, 11, -1 ], [ 7, 2 ], [ 8, 2, 13, -1, 12, -1 ], 
          [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], [ 13, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 13, -1, 11, -1, 10, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 13, -1, 11, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 11, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 13, -1, 12, -1, 11, -1, 10, -1, 9, -1, 
              8, -1 ], [ 5, -1, 4, -1, 5, 1, 4, 1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 13, -1, 11, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 13, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 13, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 13, -1, 12, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 13, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 13, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 12, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 13, -1, 11, -1, 6, -1 ], 
          [ 4, 2, 11, -1, 9, -1 ], [ 5, 2, 13, -1, 11, -1, 10, -1 ], 
          [ 6, 2, 13, -1, 11, -1 ], [ 7, 2 ], [ 8, 2, 13, -1, 12, -1 ], 
          [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], [ 13, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 13, -1, 11, -1, 10, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 13, -1, 11, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 12, -1, 11, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 13, -1, 12, -1, 11, -1, 10, -1, 9, -1, 
              8, -1 ], [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 13, -1, 11, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 13, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 13, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 13, -1, 12, -1, 11, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 12, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 13, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 13, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 12, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2 ], [ 4, 2, 6, -1 ], [ 5, 2 ], 
          [ 6, 2 ], [ 7, 2 ], [ 8, 2, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], 
          [ 11, 2 ], [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ]
            , [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 13, -1, 12, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 12, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 12, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 13, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 12, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 12, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ], 
          [ 11, -1, 3, -1, 11, 1, 3, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 12, -1, 8, -1 ], [ 4, 2, 6, -1 ],
          [ 5, 2, 13, -1, 12, -1, 10, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 8, 2, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], 
          [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 8, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 13, -1, 12, -1, 10, -1, 8, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 13, -1, 12, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 13, -1, 10, -1, 9, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 13, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 13, -1, 12, -1, 11, -1, 9, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 13, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 12, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 12, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 11, -1, 3, -1, 11, 1, 3, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 13, -1, 9, -1 ], [ 4, 2, 6, -1 ],
          [ 5, 2, 13, -1, 12, -1 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2, 12, -1 ], 
          [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], [ 12, 2 ], [ 13, 2 ], 
          [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 9, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 13, -1, 12, -1, 9, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 13, -1, 12, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 13, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 12, -1, 11, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 13, -1, 12, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 13, -1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 8, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 11, -1, 10, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 11, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 13, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 13, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 13, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 13, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 11, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 12, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 2, -1, 10, 1, 2, 1, 12, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 12, -1 ], 
          [ 11, -1, 3, -1, 11, 1, 3, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2 ], 
          [ 5, 2, 12, -1, 10, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 8, 2, 13, -1, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], 
          [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 12, -1, 10, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 12, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 11, -1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 11, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 12, -1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 13, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 12, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 13, -1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 13, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 4, -1, 8, 1, 4, 1, 12, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 9, -1, 4, -1, 9, 1, 4, 1, 13, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 11, -1, 3, -1, 11, 1, 3, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 13, [ [ 1, 2, 4, -1 ], [ 2, 2 ], [ 3, 2, 6, -1 ], [ 4, 2, 12, -1, 9, -1 ],
          [ 5, 2, 13, -1, 10, -1 ], [ 6, 2 ], [ 7, 2 ], 
          [ 8, 2, 13, -1, 12, -1 ], [ 9, 2, 13, -1 ], [ 10, 2 ], [ 11, 2 ], 
          [ 12, 2 ], [ 13, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 13, -1, 10, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 13, -1, 10, -1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 2, -1, 5, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 13, -1, 12, -1, 11, -1, 10, -1, 9, -1, 
              8, -1 ], [ 5, -1, 4, -1, 5, 1, 4, 1, 13, -1, 10, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 12, -1, 11, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 12, -1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 13, -1, 10, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 13, -1, 12, -1, 9, -1 ], 
          [ 7, -1, 4, -1, 7, 1, 4, 1, 11, -1 ], 
          [ 7, -1, 5, -1, 7, 1, 5, 1, 11, -1 ], 
          [ 7, -1, 6, -1, 7, 1, 6, 1, 13, -1, 12, -1, 11, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 2, -1, 8, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 13, -1, 11, -1, 10, -1 ], 
          [ 8, -1, 5, -1, 8, 1, 5, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 6, -1, 8, 1, 6, 1, 13, -1, 12, -1 ], 
          [ 8, -1, 7, -1, 8, 1, 7, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 1, -1, 9, 1, 1, 1, 13, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ], 
          [ 9, -1, 3, -1, 9, 1, 3, 1, 12, -1, 11, -1 ], 
          [ 9, -1, 5, -1, 9, 1, 5, 1, 13, -1, 12, -1 ], 
          [ 9, -1, 6, -1, 9, 1, 6, 1, 13, -1 ], 
          [ 9, -1, 7, -1, 9, 1, 7, 1, 13, -1 ], 
          [ 10, -1, 1, -1, 10, 1, 1, 1, 11, -1 ], 
          [ 10, -1, 3, -1, 10, 1, 3, 1, 12, -1 ], 
          [ 10, -1, 4, -1, 10, 1, 4, 1, 12, -1 ], 
          [ 11, -1, 1, -1, 11, 1, 1, 1, 12, -1 ], 
          [ 11, -1, 2, -1, 11, 1, 2, 1, 13, -1, 12, -1 ], 
          [ 11, -1, 3, -1, 11, 1, 3, 1, 13, -1 ], 
          [ 11, -1, 4, -1, 11, 1, 4, 1, 13, -1 ], 
          [ 12, -1, 1, -1, 12, 1, 1, 1, 13, -1 ] ] ], 
  [ 10, [ [ 1, 2, 4, -1 ], [ 2, 2, 5, -1 ], [ 3, 2, 9, -1, 7, -1, 6, -1 ], 
          [ 4, 2 ], [ 5, 2 ], [ 6, 2 ], [ 7, 2 ], [ 8, 2 ], [ 9, 2 ], 
          [ 10, 2 ], [ 2, -1, 1, -1, 2, 1, 1, 1, 3, -1 ], 
          [ 3, -1, 1, -1, 3, 1, 1, 1, 5, -1 ], 
          [ 3, -1, 2, -1, 3, 1, 2, 1, 6, -1 ], 
          [ 4, -1, 2, -1, 4, 1, 2, 1, 9, -1, 7, -1, 6, -1, 5, -1 ], 
          [ 4, -1, 3, -1, 4, 1, 3, 1, 7, -1 ], 
          [ 5, -1, 1, -1, 5, 1, 1, 1, 7, -1 ], 
          [ 5, -1, 3, -1, 5, 1, 3, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 5, -1, 4, -1, 5, 1, 4, 1, 10, -1, 9, -1 ], 
          [ 6, -1, 1, -1, 6, 1, 1, 1, 8, -1 ], 
          [ 6, -1, 2, -1, 6, 1, 2, 1, 10, -1, 9, -1, 8, -1 ], 
          [ 6, -1, 3, -1, 6, 1, 3, 1, 9, -1 ], 
          [ 6, -1, 4, -1, 6, 1, 4, 1, 9, -1 ], 
          [ 6, -1, 5, -1, 6, 1, 5, 1, 10, -1 ], 
          [ 7, -1, 1, -1, 7, 1, 1, 1, 10, -1, 9, -1 ], 
          [ 7, -1, 2, -1, 7, 1, 2, 1, 8, -1 ], 
          [ 7, -1, 3, -1, 7, 1, 3, 1, 9, -1 ], 
          [ 8, -1, 1, -1, 8, 1, 1, 1, 9, -1 ], 
          [ 8, -1, 3, -1, 8, 1, 3, 1, 10, -1 ], 
          [ 9, -1, 2, -1, 9, 1, 2, 1, 10, -1 ] ] ] ];
