#############################################################################
##
#W pointnorm.gi                Package Coclass                   Bettina Eick
##

#############################################################################
##
#F SetUpForNormalizer( p )
##
SetUpForNormalizer := function( p )
    local G, g, U, w, h, d, l, m;
    
    # the permutation
    G := SymmetricGroup(p);
    g := GeneratorsOfGroup(G)[1]; # g = (1,..,p);
    U := Normalizer( G, Subgroup( G, [g] ) );
    w := IntFFE( PrimitiveRoot( GF(p) ) );
    h := Filtered( Elements(U), x -> g^x = g^w );
    h := Filtered( h, x -> p^x = p );
    
    # the initial matrix
    d := PRootDiagonal( 1, p );
    l := d^w;
    m := FindConjugatingMats( [d], [l] );

    # that's it
    return rec( perm := h[1], init := m[1] );
end;

#############################################################################
##
#F FiniteNormalizerMatrices( G ) . . . . . . . . . . .the outer automorphisms
##
FiniteNormalizerMatrices := function(G)
    local s, p, q, mats, h, d, e, i, w;

    s := G!.param;
    p := G!.prime;
    q := p^(s-1);

    if p = 3 then
        w := [[0,1],
              [1,0]];
        h := PermutationMat( (1,2), 3 );
    elif p = 5 then 
        w := [[0,1,-1,0], 
              [0,1,-1,1], 
              [1,0,-1,1], 
              [1,0,0,0]];
        h := PermutationMat( (1,2,4,3), 5 ); 
    elif p = 7 then
        w := [ [ 0, 0, 1, -1, 0, 0 ],
               [ 0, 0, 1, -1, 0, 1 ],
               [ 0, 1, 0, -1, 0, 1 ],
               [ 0, 1, 0, -1, 1, 0 ],
               [ 1, 0, 0, -1, 1, 0 ],
               [ 1, 0, 0,  0, 0, 0 ] ];
        h := PermutationMat( (1,3,2,6,4,5), 7 ); 
    else 
        w := SetUpForNormalizer( p );
        h := PermutationMat( w.perm, p );
        w := w.init;
    fi;

    # the first one is different
    mats := [];
    mats[1] := DiagonalBlockMat( List( [1..q], x -> w ) );
   
    # the others are by induction
    d := p-1;
    e := p^(s-2);
    for i in [2..s] do
        w := IdentityMat( d );
        w := KroneckerProduct( h, w );
        mats[i] := DiagonalBlockMat( List( [1..e], x -> w ) );
        d := d * p;
        e := e / p;
    od;
    return Reversed( mats );
end;

#############################################################################
##
#F PcpFiniteNormalizer( G )
##
PcpFiniteNormalizer := function( G )
    local g, p, s, l, w, a, i, h, t, b, r, H, K, k, U, efa;
  
    # set up
    p := G!.prime;
    s := G!.param;
    g := G!.mins;
    l := Length(g);
    w := IntFFE( PrimitiveRoot( GF(p) ) );

    # get outer automorphisms of G
    a := List( [1..l], x -> [] );
    for i in [1..l] do
        h := List( [1..l], x -> g[i] );
        h[i] := g[i]^w;
        a[i] := Tuple( h );
    od;
    t := CgsParallel( g, a );
    for i in [1..l] do
        h := t[2]{[1..Length(t[2])]}[i];
        a[i] := GroupHomomorphismByImagesNC( G, G, t[1], h );
    od;

    # get corresponding matrices and relative orders
    b := FiniteNormalizerMatrices( G );
    r := List( [1..l], x -> p - 1 ); 

    # add centralizing -1
    Add( a, IdentityMapping(G) );
    Add( b, -IdentityMat( p^(s-1)*(p-1) ) );
    Add( r, 2 );
    l := l + 1;
    
    # create extension
    H := AbelianPcpGroup( l, r );
    K := SplitExtensionByAutomorphisms( G, H, a ); 
    k := Igs(K);

    # add matrices 
    K!.mats := Concatenation(b, G!.mats);

    # add original group and translate infos from G to U
    U := SubgroupByIgs(K, k{[l+1..Length(k)]} );
    U!.param := G!.param;
    U!.prime := G!.prime;
    U!.index := G!.param-1;
    U!.mats  := G!.mats;
    U!.mins  := List( G!.mins, x -> MappedVector(Exponents(x), Igs(U)));
    U!.maxi  := List( G!.maxi, x -> SubgroupByIgs(K, List(Igs(x), y -> 
                MappedVector(Exponents(y), Igs(U)))));

    # add info to normalizer 
    K!.pointgroup := U;
    K!.param := G!.param;
    K!.prime := G!.prime;
    K!.index := G!.param-1;

    ## add special efa series for inductions
    #efa := PStepCentralSeries(U, U!.prime);
    #SetEfaSeries( K, Concatenation([K], efa) );

    return K;
end;
    
#############################################################################
##
#F WreathFiniteNormalizer( N, s, i, p )
##
InstallMethod( WreathFiniteNormalizer, true, [IsGroup, IsInt], 0,
function( N, i )
    local s, p, G, U, M;

    # get params 
    s := N!.param;
    p := N!.prime;
    if i = s-1 then return N; fi;

    # get subgroup
    G := N!.pointgroup;
    U := WreathPointGroup(G, i);

    # find normalizer
    M := Normalizer(N,U);
    M!.pointgroup := U;
    M!.param := s;
    M!.prime := N!.prime;
    M!.index := i;

    # do a check
    if p> 2 and Index(M,U) <> ((p-1)^(i+1) * p^(s-i-1) * 2) then 
        Error("wrong norm"); 
    fi; 

    return M;
end);

InstallOtherMethod( WreathFiniteNormalizer, true, [IsInt, IsInt, IsInt], 0,
function( s, i, p )
    local G, N;
    G := WreathPointGroup(s,p);

    if p = 2 then
        N := G;
        N!.pointgroup := G;
    else
        N := PcpFiniteNormalizer(G);
    fi;

    return WreathFiniteNormalizer(N, i);
end);

InstallOtherMethod( WreathFiniteNormalizer, true, [IsInt, IsInt], 0,
function( s, p )
    return WreathFiniteNormalizer(s,s-1,p);
end);

