#############################################################################
##
#W xtree.gi                 Package Coclass                      Bettina Eick
##

#Coclass := function(G)
#    local l, n;
#    l := Length(LowerCentralSeries(G))-1;
#    n := Length(Factors(Size(G)));
#    return n-l;
#end;

#############################################################################
##
#F Some helper functions
##

IsTerminal := function( G ) return not IsCapable(G); end;

EliminateMainLine := function( K, cap, aut )
    local sub;
    sub := Filtered([1..Length(cap)], x -> aut[x] = aut[1]);
    while Length(sub) > 1 do
        if IsIsomorphicPGroup( K, cap[sub[1]] ) then
            sub := [sub[1]];
        else
            sub := sub{[2..Length(sub)]};
        fi;
    od;
    sub := Difference( [1..Length(cap)], sub );
    return cap{sub};
end;

IsRoot := function( G, roots )
    if not Size(G) in List( roots, x -> x[1] ) then return false; fi;
    return IdGroup(G) in roots;
end;

#############################################################################
##
#F Some print functions
##

WIDTH := 25;
DEPTH := 40;
SSIZE := [1000, 700];

PrintScale := function( Sheet, p, s, r, l )
    local y, i, t;

    # the top line
    Text( Sheet, FONTS.normal, 20, 30, "|G|" );
    Text( Sheet, FONTS.normal, 100, 30, "tree" );

    # the first columns
    y := 30;
    for i in [s..l] do
        y := y + 40;
        t := Concatenation( String(p), "^", String(i+r-s));
        Text( Sheet, FONTS.normal, 20, y, t );
        Text( Sheet, FONTS.normal, 60, y, String(i) );
    od;
end;

StringOfPcp := function( g )
    local e, s, i;
    if g = g^0 then return "id"; fi;
    e := Exponents(g);
    s := [];
    for i in [1..Length(e)] do
        if e[i] <> 0 and Length(s) > 0 then s := Concatenation(s,"*"); fi;
        if e[i] = 1 then s := Concatenation(s, "g", String(i)); fi;
        if e[i] <> 0 and e[i] <> 1 then
            s := Concatenation(s, "g", String(i),"^",String(e[i]));
        fi;
    od;
    return s;
end;

PrintPresentation := function( Sheet, G )
    local x, y, pcp, gens, rels, i, r, g, c, t, j, h;

    y := 70;
    x := 400;
    pcp  := Pcp(G);
    gens := GeneratorsOfPcp( pcp );
    rels := RelativeOrdersOfPcp( pcp );
    for i  in [ 1 .. Length( gens ) ]  do
        if rels[i] > 0  then
            r := rels[i];
            g := gens[i];
            c := StringOfPcp(g^r);
            t := Concatenation(StringOfPcp(g), "^", String(r), " = ",c);
            Text( Sheet, FONTS.small, x, y, t );
            y := y + 10;
        fi;
    od; 
    for i  in [ 1 .. Length( gens ) ]  do
        for j  in [ 1 .. i - 1 ]  do
            g := gens[i];
            h := gens[j];
            c := gens[i] ^ gens[j];
            if c <> g  then
                c := StringOfPcp(c);
                t := Concatenation(StringOfPcp(g),"^",StringOfPcp(h)," = ",c);
                Text( Sheet, FONTS.small, x, y, t );
                y := y + 10;
            fi;
        od;
    od;
end;

StringIt := function(t)
    if IsString(t) then return t; fi;
    if IsInt(t) then return String(t); fi;
    if IsList(t) then 
       return Concatenation(List(t, x->Concatenation("-",String(x))));
    fi;
end;

PrintVertex := function( Sheet, cl, nr, t, v )
    local x, y;

    # set up x and y values
    x := 100 + WIDTH * (nr-1);
    y := 70  + DEPTH * cl;
    if not IsBool(v) and x < v[1] then return false; fi;

    # print data
    Disc( Sheet, x, y, 3 );
    if not IsBool(v) then 
        Line( Sheet, v[1], v[2], x-v[1], y-v[2] );
    fi;
    if not IsBool(t) then 
        Text( Sheet, FONTS.small, x+2, y, StringIt(t) ); 
    fi;

    # return place
    return [x, y];
end;

#############################################################################
##
#F DrawCoclassTree(G, p, s, l, opt) . . . . draw tree for G from class s to l
##
## G is a pcp group corresponding to a pro-p-group 
##   or a pcp or pc group corresponding to a finite p-group of class >= 2
##
## s is a positive integer 
## l is a positive integer with l >= s or l is false (= infinity)
## p is the relevant prime
##
## opt is an optional record which might contain
##     opt.pres -- display the presentation of G on the sheet
##     opt.func -- opt.func(H) is displayed for every vertex H
##     opt.bran -- draw branch of G_s only
##     opt.full -- draw all terminals without collecting
##
DrawCoclassTree := function( arg )
    local G, H, F, K, p, s, l, r, opt, Title, Sheet, 
          grp, nex, des, ter, cap, res, aut,
          i, j, d, g, v, a, c;

    # set up
    G := arg[1];
    p := arg[2];
    s := arg[3];
    l := arg[4];
    if l = false then l := 100; fi;
    if Length(arg) = 5 then opt := arg[5]; else opt := rec(); fi;

    # set up p-quotient of G
    if IsPcpGroup(G) then 
        F := PcpGroupToFpGroup(G);
    elif IsPcGroup(G) then 
        F := FpGroupPcGroup(G);
    elif IsFpGroup(G) then 
        F := G;
    fi;
    H := Pq(F : Prime := p, ClassBound := s);
    r := Length(Factors(Size(H)))-s;

    # if desired then determine next class
    if IsBound(opt.bran) then 
        K := Pq(F : Prime := p, ClassBound := s+1); 
    fi;

    # set up graphic sheet with scale
    Title := "coclass tree";
    Sheet := GraphicSheet( Title, SSIZE[1], SSIZE[2] );
    PrintScale( Sheet, p, s, s+r, s+25 );
    Disc( Sheet, 100, 70, 3 );

    # add presentation to sheet
    if IsBound(opt.pres) then PrintPresentation( Sheet, G ); fi;

    # set up for iteration
    grp := [[H,[100, 70]]];
    res := [[H]];
    c := false;
    
    # compute iterated descendants
    for i in [1..l-s] do
        nex := [];
        j := 1;
        for d in grp do
            des := PqDescendants( d[1] : StepSize := 1 );
            ter := Filtered( des, IsTerminal );
            cap := Filtered( des, IsCapable );
            Add( res, des );
            
            # cut of main line if desired
            if IsBound(opt.bran) and i = 1 then
                aut := List( cap, x -> Size(AutomorphismGroup(x)) );
                SortParallel( aut, cap, function(a,b) return a>b; end );
                cap := EliminateMainLine( K, cap, aut ); 
            fi;

            # draw capables
            for g in cap do
                if IsBound(opt.func) then c:=opt.func(g); fi;
                repeat
                    v := PrintVertex( Sheet, i, j, c, d[2]); 
                    j := j + 1;
                until not IsBool(v); 
                Add( nex, [g, v] );
            od;
            
            # draw terminals
            if IsBound(opt.full) or IsBound(opt.func) then
                for g in ter do
                    if IsBound(opt.func) then c:=opt.func(g); fi;
                    repeat
                        v := PrintVertex( Sheet, i, j, c, d[2]); 
                        j := j + 1;
                    until not IsBool(v); 
                od;
            else
                a := Length(ter);
                if a > 0 then 
                    repeat
                        v := PrintVertex( Sheet, i, j, a, d[2] );
                        j := j + 1;
                    until not IsBool(v);
                fi;
            fi;
        od;

        # reset for next level
        grp := nex;
        if Length(grp) = 0 then return res; fi;
    od;
    return res;
end;

#############################################################################
##
#F DrawCoclassHeader(p, c, d, l)
##
DrawCoclassHeader := function( p, c, d, l )
    local H, Title, Sheet, grp, nex, des, cap, ter, sub, str, res, col,
          i, j, k, h, g, v, r;

    # check
    if d > c+1 then return []; fi;

    # start with elementary abelian group p^d
    H := ElementaryAbelianGroup(p^d);
    res := [];

    # set up graphic sheet
    Title := Concatenation( "Coclass header:   cc = ", String(c), 
                            "   and   p = ", String(p), 
                            "   and   d = ", String(d) );
    Sheet := GraphicSheet( Title, 600, 700 );
    PrintScale( Sheet, p, 1, d, 20 );

    # set up for iteration
    if Coclass(H) = c then 
        grp := [[H,[100, 70]]];
        Disc( Sheet, 100, 70, 3 ); 
        Add( res, H );
    else
        grp := [[H,false]];
    fi;
    j := List( [1..l], x -> 1 );
    
    # compute iterated descendants
    while Length(grp) > 0 do
        nex := [];
        for h in grp do

            # check coclass
            r := Coclass(h);

            # get desired descendants
            des := PqDescendants( h[1] : OrderBound := l, StepSize := c-r+1 );
            Print("got ",Length(des), " Descendants to check \n");

            # split
            ter := Filtered( des, IsTerminal );
            cap := Filtered( des, IsCapable );
 
            # draw and add capables of coclass c
            sub := Filtered( cap, x -> Coclass(x) = c );
            for g in sub do
                i := Length(Factors(Size(g)))-d;
                repeat
                    v := PrintVertex(Sheet,i,j[i],false,h[2]);
                    j[i] := j[i] + 1;
                until not IsBool(v); 
                Add( nex, [g, v] ); 
            od;

            # add capables of coclass < c
            sub := Filtered( cap, x -> Coclass(x) < c );
            for g in sub do Add( nex, [g, false] ); od;
            
            # draw terminals of coclass = c
            sub := Filtered( ter, x -> Coclass(x) = c );
            col := Collected( List( sub, x -> Length(Factors(Size(x))) ) );
            for k in col do
                repeat
                    i := k[1]-d;
                    v := PrintVertex(Sheet,i,j[i],k[2],h[2]);
                    j[i] := j[i] + 1;
                until not IsBool(v);
            od;
        od;

        # reset for next level
        grp := nex;
    od;
    return res;
end;


